<?php

namespace Teknisa\CADFIS\Services;

use Teknisa\Libs\Util\Environment;
use Doctrine\ORM\EntityManager;


class Dfs87000AutorizacaoObterXmlService {

    protected $entityManager;
    protected $environment;

    public function __construct(Environment $environment, EntityManager $entityManager){
        $this->environment  = $environment;
        $this->entityManager = $entityManager;
    }
    

    public function replicaAutorizacao($row){
        $dadosAutorizacaoInscricao = $this->getDadosAutorizacaoInscricao($row["CDEMPRESAORIG"], $row["CDINSCESTAORIG"]);

        $inscricoesReplicacao = $this->getInscricoesEmpresa($row["CDEMPRESADEST"], $this->montaIn($row["CDINSCESTADEST"]), $row["TODASINSCRICOES"]);

        $dataSet = array();
        
        $row = array(
            "CDINSCESTA" => "",
            "CDEMPRESA" => "",
            "NRINSJURAUTOXML" => "",
            "DSOBSAUTOXML" => ""
        );
       
            
        foreach($inscricoesReplicacao as $inscricao) {
            $row["CDINSCESTA"] = $inscricao["CDINSCESTA"];
            $row["CDEMPRESA"]  = $inscricao["CDEMPRESA"];
            
            $this->removeAutorizacoes($inscricao["CDEMPRESA"], $inscricao["CDINSCESTA"]);
            
            foreach($dadosAutorizacaoInscricao as $autorizacao) {
                $row["NRINSJURAUTOXML"] = $autorizacao["NRINSJURAUTOXML"];
                $row["DSOBSAUTOXML"]    = $autorizacao["DSOBSAUTOXML"];
                $this->adicionarCamposAuditoria($row);
                array_push($dataSet, $row);  
             }
        }

        return $dataSet;
        
    }
    
    protected function montaIn($value) {
        $sql = '(';
        if($value) {
            foreach($value as $e) {
                $sql.= "'".$e."'".',';
            }
        }
        else {
            return "('Y')";
        }
        $size = strlen($sql);
        return substr($sql,0, $size-1).')';
    }
     
     
    protected function removeAutorizacoes($cdempresa, $cdinscesta) {
        $sql = "DELETE FROM AUTOOBTERXMLIE
                WHERE CDEMPRESA = :P_CDEMPRESA
                AND CDINSCESTA  = :P_CDINSCESTA";
                
        $params = array(
            'P_CDEMPRESA' => $cdempresa,
            'P_CDINSCESTA' => $cdinscesta
        );
        
        return $this->entityManager->getConnection()->prepare($sql)->execute($params);
    } 
    
    protected function getDadosAutorizacaoInscricao($cdempresa, $cdinscesta) {
        
        $sql = "SELECT * 
                FROM AUTOOBTERXMLIE
                WHERE CDEMPRESA = :P_CDEMPRESA
                AND CDINSCESTA  = :P_CDINSCESTA";
                
        $params = array(
            'P_CDEMPRESA' => $cdempresa,
            'P_CDINSCESTA' => $cdinscesta
        );
        
        return $this->entityManager->getConnection()->fetchAll($sql, $params);
    }
    
    protected function getInscricoesEmpresa($cdempresa, $inscricoes, $todas) {
        $sql = "SELECT DISTINCT CDINSCESTA, CDEMPRESA
                FROM INSCRESTAD
                WHERE CDEMPRESA  = :P_CDEMPRESA
                AND (CDINSCESTA IN $inscricoes
                OR :T_CDINSCESTA = 'Y')";
                
         $params = array(
            'P_CDEMPRESA' => $cdempresa,
            "T_CDINSCESTA" => $todas
        );
        
        return $this->entityManager->getConnection()->fetchAll($sql, $params);
    }

    protected function adicionarCamposAuditoria(&$row) {
        $currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
        $row['NRORG'] = (isset($row['NRORG']) && !empty($row['NRORG'])) ? $row['NRORG'] : $this->environment->getNrOrgTrab();
        $row['IDATIVO'] = isset($row['IDATIVO']) ? ($row['IDATIVO'] ?: 'S') : 'S';
        $row['DTULTATU'] = $currentTime;
        $row['NRORGULTATU'] = $this->environment->getNrOrgTrab();
        $row['CDOPERULTATU'] = $this->environment->getCdOperador();
        $row['DTINCLUSAO'] = $currentTime;
        $row['NRORGINCLUSAO'] = $this->environment->getNrOrgTrab();
        $row['CDOPERINCLUSAO'] = $this->environment->getCdOperador();
        $row["__is_new"] = true;
    }

}